package org.jeecg.modules.employRedister.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.employRedister.entity.EmployRedister;
import org.jeecg.modules.employRedister.service.IEmployRedisterService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: 报名材料提交表
 * @Author: jeecg-boot
 * @Date:   2024-12-21
 * @Version: V1.0
 */
@Api(tags="报名材料提交表")
@RestController
@RequestMapping("/employRedister/employRedister")
@Slf4j
public class EmployRedisterController extends JeecgController<EmployRedister, IEmployRedisterService> {
	@Autowired
	private IEmployRedisterService employRedisterService;
	
	/**
	 * 分页列表查询
	 *
	 * @param employRedister
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "报名材料提交表-分页列表查询")
	@ApiOperation(value="报名材料提交表-分页列表查询", notes="报名材料提交表-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<EmployRedister>> queryPageList(EmployRedister employRedister,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<EmployRedister> queryWrapper = QueryGenerator.initQueryWrapper(employRedister, req.getParameterMap());
		Page<EmployRedister> page = new Page<EmployRedister>(pageNo, pageSize);
		IPage<EmployRedister> pageList = employRedisterService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param employRedister
	 * @return
	 */
	@AutoLog(value = "报名材料提交表-添加")
	@ApiOperation(value="报名材料提交表-添加", notes="报名材料提交表-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody EmployRedister employRedister) {
		employRedisterService.save(employRedister);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param employRedister
	 * @return
	 */
	@AutoLog(value = "报名材料提交表-编辑")
	@ApiOperation(value="报名材料提交表-编辑", notes="报名材料提交表-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody EmployRedister employRedister) {
		employRedisterService.updateById(employRedister);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "报名材料提交表-通过id删除")
	@ApiOperation(value="报名材料提交表-通过id删除", notes="报名材料提交表-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		employRedisterService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "报名材料提交表-批量删除")
	@ApiOperation(value="报名材料提交表-批量删除", notes="报名材料提交表-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.employRedisterService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "报名材料提交表-通过id查询")
	@ApiOperation(value="报名材料提交表-通过id查询", notes="报名材料提交表-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<EmployRedister> queryById(@RequestParam(name="id",required=true) String id) {
		EmployRedister employRedister = employRedisterService.getById(id);
		if(employRedister==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(employRedister);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param employRedister
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, EmployRedister employRedister) {
        return super.exportXls(request, employRedister, EmployRedister.class, "报名材料提交表");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, EmployRedister.class);
    }

}
