package org.jeecg.modules.employUserInfo.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.employUserInfo.entity.EmployUserInfo;
import org.jeecg.modules.employUserInfo.service.IEmployUserInfoService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: 用户信息表
 * @Author: jeecg-boot
 * @Date:   2024-10-24
 * @Version: V1.0
 */
@Api(tags="用户信息表")
@RestController
@RequestMapping("/employUserInfo/employUserInfo")
@Slf4j
public class EmployUserInfoController extends JeecgController<EmployUserInfo, IEmployUserInfoService> {
	@Autowired
	private IEmployUserInfoService employUserInfoService;
	
	/**
	 * 分页列表查询
	 *
	 * @param employUserInfo
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "用户信息表-分页列表查询")
	@ApiOperation(value="用户信息表-分页列表查询", notes="用户信息表-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<EmployUserInfo>> queryPageList(EmployUserInfo employUserInfo,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<EmployUserInfo> queryWrapper = QueryGenerator.initQueryWrapper(employUserInfo, req.getParameterMap());
		Page<EmployUserInfo> page = new Page<EmployUserInfo>(pageNo, pageSize);
		IPage<EmployUserInfo> pageList = employUserInfoService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param employUserInfo
	 * @return
	 */
	@AutoLog(value = "用户信息表-添加")
	@ApiOperation(value="用户信息表-添加", notes="用户信息表-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody EmployUserInfo employUserInfo) {
		employUserInfoService.save(employUserInfo);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param employUserInfo
	 * @return
	 */
	@AutoLog(value = "用户信息表-编辑")
	@ApiOperation(value="用户信息表-编辑", notes="用户信息表-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody EmployUserInfo employUserInfo) {
		employUserInfoService.updateById(employUserInfo);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "用户信息表-通过id删除")
	@ApiOperation(value="用户信息表-通过id删除", notes="用户信息表-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		employUserInfoService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "用户信息表-批量删除")
	@ApiOperation(value="用户信息表-批量删除", notes="用户信息表-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.employUserInfoService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "用户信息表-通过id查询")
	@ApiOperation(value="用户信息表-通过id查询", notes="用户信息表-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<EmployUserInfo> queryById(@RequestParam(name="id",required=true) String id) {
		EmployUserInfo employUserInfo = employUserInfoService.getById(id);
		if(employUserInfo==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(employUserInfo);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param employUserInfo
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, EmployUserInfo employUserInfo) {
        return super.exportXls(request, employUserInfo, EmployUserInfo.class, "用户信息表");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, EmployUserInfo.class);
    }

}
